#include <NewPing.h>
#include <SoftwareSerial.h>

#define bluetoothRx 6
#define bluetoothTx 5
#define sensorTrig 9
#define sensorEcho 10
#define redLed 12
#define blueLed 13
#define soundSignal 11
#define frequency 1000
#define maxDistance 20

SoftwareSerial bluetooth(bluetoothRx, bluetoothTx);
NewPing sonar(sensorTrig, sensorEcho);

void playAmbulance() {
  int siren[] = {800, 1200, 1400, 1800, 2000, 2200, 2400, 2800, 3000, 3200, 3400, 3600, 3800, 4000, 4200, 4400};

  for(int i = 0; i < sizeof(siren) / sizeof(int); i++) {
    tone(soundSignal, siren[i]);
    delay(150);
  }

  noTone(soundSignal);
}

void playPolice() {
  int siren[] = {1000, 2000, 3000, 4000, 5000, 6000, 7000, 8000};

  for(int i = 0; i < sizeof(siren) / sizeof(int); i++) {
    tone(soundSignal, siren[i]);
    delay(150);
  }

  noTone(soundSignal);
}

void playFirefighters() {
  int siren[] = {200, 400, 600, 800, 1000, 1200, 1400, 1600};

  for(int i = 0; i < sizeof(siren) / sizeof(int); i++) {
    tone(soundSignal, siren[i]);
    delay(150);
  }

  noTone(soundSignal);
}

void ledOnOff(int ledType){
  for(int i = 0; i < 50; i++){
    if(i % 5 == 0) {
      digitalWrite(ledType, HIGH);
      if(ledType == redLed) {
        playFirefighters();
      } else {
        playAmbulance();
      }
      delay(100);
    } else {
      digitalWrite(ledType, LOW);
      delay(100);
    }
  }
}

void ledsOnOff(int ledType1, int ledType2){
  for(int i = 0; i < 50; i++){
    if(i % 5 == 0) {
      digitalWrite(ledType1, HIGH);
      digitalWrite(ledType2, HIGH);
      playPolice();
      delay(100);
    } else {
      digitalWrite(ledType1, LOW);
      digitalWrite(ledType2, LOW);
      delay(100);
    }
  }
}

void setup() {
  // put your setup code here, to run once:
  pinMode(redLed, OUTPUT);
  pinMode(blueLed, OUTPUT);
  pinMode(soundSignal, OUTPUT);

  Serial.begin(9600);
  bluetooth.begin(9600);

}

void loop() {
  // put your main code here, to run repeatedly:
  unsigned int distance = sonar.ping_cm();

  if(Serial.available()) {
    char input = Serial.read();

    if(input == '0' && distance <= maxDistance) {
      ledOnOff(blueLed);
      digitalWrite(redLed, LOW);
    } else if (input == '1' && distance <= maxDistance) {
      ledsOnOff(redLed, blueLed);
    } else if (input == '2' && distance <= maxDistance) {
      ledOnOff(redLed);
      digitalWrite(blueLed, LOW);
    }

    while(Serial.available()) {
      Serial.read();
    }
  }

}
